@@ -2,16 +2,18 @@ import json
 from typing import TypeVar, Generic, Union, Optional, Literal, List, Dict
 from datetime import datetime, date
 
+
 def to_camel_case(snake_str):
     components = snake_str.lstrip('_').split('_')
     # We capitalize the first letter of each component except the first one
     # with the 'title' method and join them together.
     return components[0] + ''.join(x.title() for x in components[1:])
 
+
 class UnitDTO(object):
     def to_dict(self):
         if type(self) is dict:
-            return dto
+            return self
         else:
             v = vars(self)
             return dict((to_camel_case(k), val) for k, val in v.items() if val is not None)
@@ -31,6 +33,7 @@ class Relationship(UnitDTO):
 
 T = TypeVar('T')
 
+
 class RelationshipArray(Generic[T], UnitDTO):
     def __init__(self, l: List[T]):
         self.relationships = l
@@ -53,10 +56,12 @@ class UnitRequest(object):
     def to_json_api(self) -> Dict:
         pass
 
+
 class UnitParams(object):
     def to_dict(self) -> Dict:
         pass
 
+
 class RawUnitObject(UnitDTO):
     def __init__(self, _id, _type, attributes, relationships):
         self.id = _id
@@ -68,6 +73,7 @@ class RawUnitObject(UnitDTO):
         v = vars(self.attributes)
         return dict((to_camel_case(k), val) for k, val in v.items() if val is not None)
 
+
 class UnitErrorPayload(object):
     def __init__(self, title: str, status: str, detail: Optional[str] = None, details: Optional[str] = None,
                  source: Optional[Dict] = None, code: Optional[str] = None):
@@ -106,6 +112,7 @@ Status = Literal["Approved", "Denied", "PendingReview"]
 Title = Literal["CEO", "COO", "CFO", "President"]
 EntityType = Literal["Corporation", "LLC", "Partnership"]
 
+
 class FullName(UnitDTO):
     def __init__(self, first: str, last: str):
         self.first = first
